@@ -1,12 +1,16 @@
 """CLI for ``tmuxp ls`` subcommand."""
 
-import argparse
+from __future__ import annotations
+
 import os
 import typing as t
 
 from tmuxp.workspace.constants import VALID_WORKSPACE_DIR_FILE_EXTENSIONS
 from tmuxp.workspace.finders import get_workspace_dir
 
+if t.TYPE_CHECKING:
+    import argparse
+
 
 def create_ls_subparser(
     parser: argparse.ArgumentParser,
@@ -16,7 +20,7 @@ def create_ls_subparser(
 
 
 def command_ls(
-    parser: t.Optional[argparse.ArgumentParser] = None,
+    parser: argparse.ArgumentParser | None = None,
 ) -> None:
     """Entrypoint for ``tmuxp ls`` subcommand."""
     tmuxp_dir = get_workspace_dir()
@@ -25,4 +29,4 @@ def command_ls(
             stem, ext = os.path.splitext(f)
             if os.path.isdir(f) or ext not in VALID_WORKSPACE_DIR_FILE_EXTENSIONS:
                 continue
-            print(stem)
+            print(stem)  # NOQA: T201 RUF100
